#
# spec file for package xfmpc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfmpc
Version:        0.3.1
Release:        bp155.3.3.1
Summary:        MPD Client for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://goodies.xfce.org/projects/applications/xfmpc
Source:         https://archive.xfce.org/src/apps/xfmpc/0.3/%{name}-%{version}.tar.bz2
Source1:        xfmpc.png
BuildRequires:  intltool
BuildRequires:  sed
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libmpd) >= 0.15.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
Recommends:     %{name}-lang = %{version}
Suggests:       mpd

%description
Xfmpc is a Music Player Daemon (MPD) client application for the
Xfce desktop environment.

%lang_package

%prep
%setup -q
sed -i 's/Icon=stock_volume/Icon=xfmpc/' xfmpc.desktop.in

%build
%configure
%make_build

%install
%make_install
install -D -m 0644 -p %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file %{name}

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS IDEAS NEWS README.md THANKS
%license COPYING
%{_bindir}/xfmpc
%{_mandir}/man1/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files lang -f %{name}.lang

%changelog
* Sun Apr 23 2023 Manfred Hollstein <manfred.h@gmx.net>
- update to 0.3.1
  * Improve icon and style of clear playlist button
  * build: Fix "unhandled error" vala warning
  * build: Fix "never used" vala warning
  * build: Fix "access to static member" vala warning
  * Fix previous commit
  * Update copyright year
  * build: Silence compiler warnings for generated C code
  * build: Add GLib requirement
  * Fix make distcheck and update urls
  * Fix missing-prototypes
  * Update COPYING
  * Fix compilation warnings
  * use Gtk MenuButton for context button
  * Call methods from GtkDialog instead of XfceTitleDialog (#8)
  * add parenthesis around expression
  * Adds new README.md and updates AM_INIT_AUTOMAKE macro with
    foreign option
  * Use 'multimedia-player' icon instead of 'stock_volume'
    (Bug #15636)
  * Translation Updates
* Sat Jun 22 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- update to 0.3.0
  * Stable release of 0.2.90
  * Fixed build issues
  * Translation updates
- replace ed with sed
* Tue Mar  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 0.2.90
  * GTK3 Port
  * Resume playback after replacing queue (bxo#9100)
  * Translation updates
* Tue Oct  3 2017 jengelh@inai.de
- Ensure neutrality of description. Remove redundant %%clean section.
* Mon Dec 26 2016 seife+obs@b1-systems.com
- update to version 0.2.3
  - fix ambiguity between GLib.Timeout and Gtk.Timeout (bxo#11062)
  - use AC_CONFIG_HEADERS in configure.in.in (bxo#11063)
  - unlock mutex in connect instead of connect_thread, otherwise
    we'd try to unlock an unlocked mutex (bxo#10366)
  - translation updates
- do not package ChangeLog file, NEWS is enough
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- split off -lang subpackage
* Sun Oct 23 2011 gber@opensuse.org
- update to version 0.2.2
  - add status-icon to hide Xfmpc and keep it running in the
    background
  - add a Shortcuts dialog to show existing shortcuts
  - tweak visual aspects
  - fix misc bugs
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Thu Feb  3 2011 gber@opensuse.org
- update to version 0.2.1
  - support for consume and single modes
  - set Xfmpc window title to what is currently playing in mpd
  - port to libxfce4ui
  - port to automake 1.11
  - Remove dependency on xfce4-vala
  - bugfixes
* Wed Dec 29 2010 gber@opensuse.org
- corrected group
- corrected license
- imporved summary, description
- added missing build dependencies
- remove unsupported locales
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 0.2.0
* Fri Apr  3 2009 prusnak@suse.cz
- updated to 0.1.0
  * 0.1.0
  - Preferences dialog for the MPD server and the appearance
  - An about dialog
  - Display the song position in the playlist
  - The database browser shows filenames already in the playlist in bold
  - A statusbar with the number of songs and total time of the playlist
  - A Replace item in the database browser context menu
  - A Browse item in the database browser (search results) and the playlist
    context menus to go to the directory of a song
  - An information item in the playlist context menu
  - Fix misc bugs
  - New translations: Swedish, Turkish, Portuguese, Czech, Basque, Italian,
    Spanish, Catalan
  * 0.0.7
  - Add a search entry in the database browser
  - Add a right click menu in the database browser to add the selected songs
  - Add a right click menu in the playlist to remove the selected songs
  - Fix misc bugs
  - New translations: Finnish, Indonesian, Japanese, Ukrainian
  * 0.0.6
  - New button that displays a context menu
  - Possibility to switch repeat and random in the context menu
  - Reload the database view on changes (mpc update)
  - Fix misc bugs
  * 0.0.5
  - Add Clear Playlist and Refresh Database buttons
  - Clean up XfmpcInterface, move GtkWindow code to main.c
  - Fix misc bugs
* Wed Apr  2 2008 prusnak@suse.cz
- updated to 0.0.4
  * 0.0.4
  - Add a database browser with the ability to add songs
  - Add behaviors in the filter entry of the playlist
  - Be more efficient with playlist refreshes
  - Fix misc bugs
  * 0.0.3
  - New widget XfmpcExtendedInterface which displays notebook pages
    selectable through a combo box
  - New widget XfmpcPlaylist with a filter entry
  - Save the state of the window (sticky window, size)
  - Installs a desktop file entry
  - Emit signals on changes instead of setting a bitfield inside
    XfmpcMpdclient
  * 0.0.2
  - Keybindings (Ctrl+B/P/S/F/V) to go backwards, play/pause, stop,
    go forwards, and open the volume slider
  - A cleaner interface to libmpd, with status handling
  - A GObjectified XfmpcMpdclient
  - A GObject XfmpcPreferences interface, so far it remembers the
    last position of the XfmpcInterface
* Sun Jan 20 2008 bwalle@suse.de
- initial package
